//==================================================== file = interfaces.c ====
//=  Program to show list of interfaces available in a computer using the     =
//=  WinPcap 4.02 interface (http://www.winpcap.org/)                         =
//=============================================================================
// Copyright (c) 1999 - 2003
// NetGroup, Politecnico di Torino (Italy)
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
//
// 1. Redistributions of source code must retain the above copyright
// notice, this list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright
// notice, this list of conditions and the following disclaimer in the
// documentation and/or other materials provided with the distribution.
// 3. Neither the name of the Politecnico di Torino nor the names of its
// contributors may be used to endorse or promote products derived from
// this software without specific prior written permission.
//
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
// "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
// LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
// A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
// OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
// SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
// LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
// DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
// THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
// (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//=============================================================================
//=  Notes:                                                                   =
//=    1) This product includes software developed by the Politecnico         =
//=       di Torino, and its contributors.                                    =
//=    2) WinPcap Developer Pack must be downloaded from                      =
//=       http://www.winpcap.org/devel.htm and unzipped.                      =
//=    3) Runs on Windows XP or Vista and assumes that one Ethernet card is   =
//=       installed (TCP/IP need not be installed).                           =
//=    4) It has a warning during compilation but doesn't make influence      =
//=    5) Libraries under Lib and Include folders must be copied to GCC       =
//=       installation folder                                                 =
//=============================================================================
//= Example execution:                                                        =
//= -------------------- Begin of program --------                            =
//= Available interfaces (Interface number: Name (Description))               =
//=                                                                           =
//= 1. rpcap://\Device\NPF_GenericDialupAdapter (Network adapter local host)  =
//=                                                                           =
//= 2. rpcap://\Device\NPF_{A5D31E6D-DDF3-4B35-AC85-39279DF56400}             =
//= -------------------- End of program --------                              =
//=============================================================================
//=  Build: gcc interfaces.c -lwpcap -lws2_32 -L.\Lib -I.\Include ...         =
//=         -o interfaces =                                                   =
//=---------------------------------------------------------------------------=
//=  Execute: interfaces                                                      =
//=---------------------------------------------------------------------------=
//=  Authors: Miguel Jimeno, Ken Christensen                                  =
//=           University of South Florida                                     =
//=           WWW: http://www.csee.usf.edu/~mjimeno                           =
//=           Email: {mjimeno, christen}@cse.usf.edu                          =
//=---------------------------------------------------------------------------=
//=  History: MJ/KJC (05/01/09) - Genesis from NetGroup's original            =
//=============================================================================
#include "pcap.h"                     // Winpcap libraries
#include "remote-ext.h"               // Winpcap libraries
#include <stdio.h>

//=============================================================================
//=  Main program                                                             =
//=============================================================================
int main()
{
  pcap_if_t *alldevs;               // list of interfaces
  pcap_if_t *d;                     // interface handler
  int i;                            // counter
  char errbuf[PCAP_ERRBUF_SIZE];    // buffer to store error messages

  // Retrieve the interface list or terminate program if there is an error
  if (pcap_findalldevs_ex(PCAP_SRC_IF_STRING, NULL, &alldevs, errbuf) == -1)
  {
    printf("*** ERROR - Error in pcap_findalldevs: %s\n", errbuf);
    exit(1);
  }

  printf("\n---------------------- Begin of program -----------------");
  printf("\nAvailable interfaces (Interface #. Name (Description))\n",i);

  i = 0; // Initialize counter
  // Print the list
  for(d=alldevs; d; d=d->next)
  {
    printf("\n%d. %s", ++i, d->name);
    // Print the description of the interface if it has one
    if (d->description)
      printf(" (%s)\n", d->description);
    else
      printf(" (No description available)\n");
  }

  // If i = 0 there is no interfaces to use, then terminate program
  if (i == 0)
  {
    printf("\n*** ERROR - No interfaces found! Make sure WinPcap is ");
    printf("installed.\n");
    return -1;
  }

  // At this point, we don't need any more the interface list. Free it
  pcap_freealldevs(alldevs);

  printf("\n---------------------- End of program ----------------------");
  return 0;
}
